# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from tetherhelix_grpc import tetherbot_pb2 as tetherhelix__grpc_dot_tetherbot__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in tetherhelix_grpc/tetherbot_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TetherBotStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentPositions = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/GetCurrentPositions',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.FromString,
                _registered_method=True)
        self.StreamRealTimePositions = channel.unary_stream(
                '/tetherhelix_grpc.TetherBot/StreamRealTimePositions',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.FromString,
                _registered_method=True)
        self.StreamMarketValue = channel.unary_stream(
                '/tetherhelix_grpc.TetherBot/StreamMarketValue',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.FromString,
                _registered_method=True)
        self.Start = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/Start',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
                _registered_method=True)
        self.Stop = channel.unary_unary(
                '/tetherhelix_grpc.TetherBot/Stop',
                request_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
                _registered_method=True)


class TetherBotServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCurrentPositions(self, request, context):
        """트레이딩 봇이 실시간 가격 데이터를 스트리밍함
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRealTimePositions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamMarketValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TetherBotServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentPositions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentPositions,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.SerializeToString,
            ),
            'StreamRealTimePositions': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamRealTimePositions,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.SerializeToString,
            ),
            'StreamMarketValue': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamMarketValue,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tetherhelix_grpc.TetherBot', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('tetherhelix_grpc.TetherBot', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TetherBot(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCurrentPositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/GetCurrentPositions',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.BatchPositionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamRealTimePositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/StreamRealTimePositions',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.PositionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamMarketValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/StreamMarketValue',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.MarketDataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/Start',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.TetherBot/Stop',
            tetherhelix__grpc_dot_tetherbot__pb2.KeyRequest.SerializeToString,
            tetherhelix__grpc_dot_tetherbot__pb2.KeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
