# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/admin.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/admin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctetherhelix_grpc/admin.proto\x12\x10tetherhelix_grpc\")\n\x0cLoginRequest\x12\x19\n\x11\x61\x64min_certificate\x18\x01 \x01(\t\"B\n\rLoginResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_auth\x18\x03 \x01(\t2U\n\tAdminAuth\x12H\n\x05Login\x12\x1e.tetherhelix_grpc.LoginRequest\x1a\x1f.tetherhelix_grpc.LoginResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_LOGINREQUEST']._serialized_start=50
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=159
  _globals['_ADMINAUTH']._serialized_start=161
  _globals['_ADMINAUTH']._serialized_end=246
# @@protoc_insertion_point(module_scope)
