# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"tetherhelix_grpc/transaction.proto\x12\x10tetherhelix_grpc\"\xd2\x02\n\x0fTransactionData\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x15\n\rbid_filled_at\x18\n \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x0b \x01(\t\x12\x16\n\x0e\x61sk_created_at\x18\x0c \x01(\t\x12\x15\n\rask_filled_at\x18\r \x01(\t\x12\x11\n\task_price\x18\x0e \x01(\x02\x12\x0f\n\x07\x61sk_fee\x18\x0f \x01(\t\x12\x0f\n\x07revenue\x18\x10 \x01(\t\"7\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62ot_name\x18\x02 \x01(\t\"Q\n\x18ScopedTransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\x03\"O\n\x14TransactionsResponse\x12\x37\n\x0ctransactions\x18\x01 \x03(\x0b\x32!.tetherhelix_grpc.TransactionData\"8\n\x10\x44\x42\x43ommitResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"^\n\x0f\x42idPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x15\n\rtether_volume\x18\x04 \x01(\x02\"3\n\x0e\x42idFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\"Y\n\x0f\x41skPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x03 \x01(\t\x12\x11\n\task_price\x18\x04 \x01(\x02\"D\n\x0e\x41skFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x61sk_fee\x18\x03 \x01(\t\",\n\x0bUuidRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xee\x05\n\x0bTransaction\x12\x66\n\x16GetCurrentTransactions\x12$.tetherhelix_grpc.TransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12i\n\x13GetPastTransactions\x12*.tetherhelix_grpc.ScopedTransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12R\n\tBidPlaced\x12!.tetherhelix_grpc.BidPlaceRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12Q\n\tBidFilled\x12 .tetherhelix_grpc.BidFillRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12R\n\tAskPlaced\x12!.tetherhelix_grpc.AskPlaceRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12Q\n\tAskFilled\x12 .tetherhelix_grpc.AskFillRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12^\n\x19OrderFailedAfterBidPlaced\x12\x1d.tetherhelix_grpc.UuidRequest\x1a\".tetherhelix_grpc.DBCommitResponse\x12^\n\x19OrderFailedAfterAskPlaced\x12\x1d.tetherhelix_grpc.UuidRequest\x1a\".tetherhelix_grpc.DBCommitResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_TRANSACTIONDATA']._serialized_start=57
  _globals['_TRANSACTIONDATA']._serialized_end=395
  _globals['_TRANSACTIONREQUEST']._serialized_start=397
  _globals['_TRANSACTIONREQUEST']._serialized_end=452
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_start=454
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_end=535
  _globals['_TRANSACTIONSRESPONSE']._serialized_start=537
  _globals['_TRANSACTIONSRESPONSE']._serialized_end=616
  _globals['_DBCOMMITRESPONSE']._serialized_start=618
  _globals['_DBCOMMITRESPONSE']._serialized_end=674
  _globals['_BIDPLACEREQUEST']._serialized_start=676
  _globals['_BIDPLACEREQUEST']._serialized_end=770
  _globals['_BIDFILLREQUEST']._serialized_start=772
  _globals['_BIDFILLREQUEST']._serialized_end=823
  _globals['_ASKPLACEREQUEST']._serialized_start=825
  _globals['_ASKPLACEREQUEST']._serialized_end=914
  _globals['_ASKFILLREQUEST']._serialized_start=916
  _globals['_ASKFILLREQUEST']._serialized_end=984
  _globals['_UUIDREQUEST']._serialized_start=986
  _globals['_UUIDREQUEST']._serialized_end=1030
  _globals['_TRANSACTION']._serialized_start=1033
  _globals['_TRANSACTION']._serialized_end=1783
# @@protoc_insertion_point(module_scope)
